@@ -1,7 +1,7 @@
 /*
- * (C) P.Horton 2004
+ * (C) P.Horton 2004,2005,2006
  *
- * $Id: lib.h 183 2006-01-16 23:32:21Z pdh $
+ * $Id: lib.h 190 2006-01-22 15:26:56Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -43,6 +43,8 @@
 # define DPUTCHAR(c)
 #endif
 
+#define align_up(p,n)		({ unsigned long a=(n), b=(unsigned long)(p); (__typeof(p))((b+a-1)&-a); })
+
 #define isspace(c)			(!!((c)==' '))
 #define isdigit(c)			({unsigned _c=(unsigned char)(c);_c>='0'&&_c<='9';})
 #define isxdigit(c)			({unsigned _c=(unsigned char)(c);(_c>='0'&&_c<='9')||(_c>='A'&&_c<='F')||(_c>='a'&&_c<='f');})
@@ -275,6 +277,7 @@ extern void *heap_image(size_t *);
 extern void heap_mark(void);
 extern void *heap_mark_image(size_t *);
 extern void heap_initrd_vars(void);
+extern void heap_set_initrd(void *, size_t);
 
 /* ext2.c */
 
@@ -365,6 +368,10 @@ extern unsigned netcon_read(void *, unsigned);
 extern unsigned netcon_write(const void *, unsigned);
 extern int netcon_enabled(void);
 
+/* exec.c */
+
+extern void clear_reloc(void);
+
 #endif
 
 /* vi:set ts=3 sw=3 cin path=include,../include: */
