@@ -1,7 +1,7 @@
 /*
- * (C) P.Horton 2004
+ * (C) P.Horton 2004,2005,2006
  *
- * $Id: heap.c 93 2004-07-27 23:17:56Z pdh $
+ * $Id: heap.c 190 2006-01-22 15:26:56Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -40,21 +40,26 @@ void heap_reset(void)
 	image_size_mark = 0;
 
 	env_remove_tag(VAR_INITRD);
+
+	clear_reloc();
+}
+
+void heap_set_initrd(void *base, size_t size)
+{
+	char text[16];
+
+	sprintf(text, "%lx", (unsigned long) base);
+	env_put("initrd-start", text, VAR_INITRD);
+	sprintf(text, "%lx", (unsigned long) base + size);
+	env_put("initrd-end", text, VAR_INITRD);
+	sprintf(text, "%x", size);
+	env_put("initrd-size", text, VAR_INITRD);
 }
 
 void heap_initrd_vars(void)
 {
-	char text[16];
-
-	if(image_size_mark) {
-
-		sprintf(text, "%lx", (unsigned long) image_base_mark);
-		env_put("initrd-start", text, VAR_INITRD);
-		sprintf(text, "%lx", (unsigned long) image_base_mark + image_size_mark);
-		env_put("initrd-end", text, VAR_INITRD);
-		sprintf(text, "%x", image_size_mark);
-		env_put("initrd-size", text, VAR_INITRD);
-	}
+	if(image_size_mark)
+		heap_set_initrd(image_base_mark, image_size_mark);
 }
 
 size_t heap_space(void)
