@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004,2005,2006
  *
- * $Id: ide.c 190 2006-01-22 15:26:56Z pdh $
+ * $Id: ide.c 194 2006-08-10 20:02:19Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -374,7 +374,7 @@ static int ide_ata_identify(struct ide_device *dev, const void *info)
 	dev->flags = 0;
 	dev->select &= REG_HEAD_SLAVE;
 
-	if(data.h[0] & (1 << 15)) {
+	if((data.h[0] & (1 << 15)) && data.h[0] != 0x848a) {
 		puts("ide: not ATA device");
 		return -1;
 	}
