@@ -1,7 +1,7 @@
 /*
- * (C) P.Horton 2004
+ * (C) P.Horton 2004,2005,2006
  *
- * $Id: shell.c 180 2005-04-10 11:09:41Z pdh $
+ * $Id: shell.c 190 2006-01-22 15:26:56Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -46,6 +46,7 @@ extern int cmnd_onerror(int);
 extern int cmnd_exit(int);
 extern int cmnd_abort(int);
 extern int cmnd_netcon(int);
+extern int cmnd_reloc(int);
 
 static int cmnd_arguments(int);
 static int cmnd_help(int);
@@ -108,6 +109,7 @@ static struct
 	{ "noop",			cmnd_noop,			0,					"[arguments ...]",										},
 	{ "sleep",			cmnd_sleep,			0,					"sleep period",											},
 	{ "netcon",			cmnd_netcon,		0,					"[host [port [port]]]",									},
+	{ "relocate",		cmnd_reloc,			0,					NULL,															},
 
 #ifdef _DEBUG
 	{ "arguments",		cmnd_arguments,	0,					"[arguments ...]",										},
@@ -186,6 +188,7 @@ static int cmnd_nvflags(int opsz)
 		"Console disabled",
 		"Horizontal menus",
 		"Probe for PCI serial",
+		"No initrd relocation",
 	};
 	unsigned indx, mask;
 	unsigned long bit;
